@@ -5,7 +5,7 @@ from django.db import models
 from django.utils import timezone
 import time
 
-from core.sistema import Inteliger
+from core.util.core import Inteliger
 from django.apps import apps
 
 
@@ -89,7 +89,7 @@ class Log(DatLog, UsrLog):
     status = models.BooleanField(null=True, default=True)
 
     class Meta:
-        managed = True
+        managed = False
         abstract = True
 
     def save(self, request_=None, *args, **kwargs):
